@@ -823,7 +823,6 @@ GDateTime *__dt = g_date_time_new_local (2009, 10, 24, 0, 0, 0);\
   TEST_PRINTF_TIME (10, 13, 13, "%l", "10");
   TEST_PRINTF ("%m", "10");
   TEST_PRINTF ("%M", "00");
-  TEST_PRINTF ("%N", "0");
   TEST_PRINTF ("%p", "AM");
   TEST_PRINTF_TIME (13, 13, 13, "%p", "PM");
   TEST_PRINTF ("%P", "am");
@@ -835,7 +834,6 @@ GDateTime *__dt = g_date_time_new_local (2009, 10, 24, 0, 0, 0);\
   //TEST_PRINTF ("%s", t_str);
   TEST_PRINTF ("%S", "00");
   TEST_PRINTF ("%t", "	");
-  TEST_PRINTF ("%W", "42");
   TEST_PRINTF ("%u", "6");
   TEST_PRINTF ("%x", "10/24/09");
   TEST_PRINTF ("%X", "00:00:00");
@@ -851,7 +849,7 @@ GDateTime *__dt = g_date_time_new_local (2009, 10, 24, 0, 0, 0);\
 static void
 test_modifiers (void)
 {
-  const gchar *oldlocale;
+  gchar *oldlocale;
 
   TEST_PRINTF_DATE (2009, 1,  1,  "%d", "01");
   TEST_PRINTF_DATE (2009, 1,  1, "%_d", " 1");
@@ -862,7 +860,7 @@ test_modifiers (void)
   TEST_PRINTF_DATE (2009, 1, 21, "%-d", "21");
   TEST_PRINTF_DATE (2009, 1, 21, "%0d", "21");
 
-  TEST_PRINTF_DATE (2009, 1,  1,  "%e", "1");
+  TEST_PRINTF_DATE (2009, 1,  1,  "%e", " 1");
   TEST_PRINTF_DATE (2009, 1,  1, "%_e", " 1");
   TEST_PRINTF_DATE (2009, 1,  1, "%-e", "1");
   TEST_PRINTF_DATE (2009, 1,  1, "%0e", "01");
@@ -894,24 +892,23 @@ test_modifiers (void)
   TEST_PRINTF_TIME ( 1, 0, 0, "%-k", "1");
   TEST_PRINTF_TIME ( 1, 0, 0, "%0k", "01");
 
-  oldlocale = setlocale (LC_ALL, "fa_IR.UTF-8");
+  oldlocale = g_strdup (setlocale (LC_ALL, NULL));
+  setlocale (LC_ALL, "fa_IR.utf-8");
   if (strstr (setlocale (LC_ALL, NULL), "fa_IR") != NULL)
     {
-      TEST_PRINTF_TIME (23, 0, 0, "%OH", "\333\262\333\263");
-      TEST_PRINTF_TIME (23, 0, 0, "%OI", "\333\261\333\261");
-      TEST_PRINTF_TIME (23, 0, 0, "%OM", "\333\260");
+      TEST_PRINTF_TIME (23, 0, 0, "%OH", "\333\262\333\263");    /* '23' */
+      TEST_PRINTF_TIME (23, 0, 0, "%OI", "\333\261\333\261");    /* '11' */
+      TEST_PRINTF_TIME (23, 0, 0, "%OM", "\333\260\333\260");    /* '00' */
 
-      TEST_PRINTF_DATE (2011, 7, 1, "%Om", "\333\267");
-      TEST_PRINTF_DATE (2011, 7, 1, "%-Om", "\333\267");
-/* These do not currently work as expected, since glib's printf
-   counts arabic digits as two characters for some reason
-      TEST_PRINTF_DATE (2011, 7, 1, "%0Om", "0\333\267");
-      TEST_PRINTF_DATE (2011, 7, 1, "%_Om", " \333\267");
-*/
+      TEST_PRINTF_DATE (2011, 7, 1, "%Om", "\333\260\333\267");  /* '07' */
+      TEST_PRINTF_DATE (2011, 7, 1, "%0Om", "\333\260\333\267"); /* '07' */
+      TEST_PRINTF_DATE (2011, 7, 1, "%-Om", "\333\267");         /* '7' */
+      TEST_PRINTF_DATE (2011, 7, 1, "%_Om", " \333\267");        /* ' 7' */
     }
   else
     g_test_message ("locale fa_IR not available, skipping O modifier tests");
   setlocale (LC_ALL, oldlocale);
+  g_free (oldlocale);
 }
 
 static void
@@ -1086,6 +1083,8 @@ test_all_dates (void)
                 else
                   week_num++;
               }
+
+            g_date_time_unref (dt);
           }
     }
 
@@ -1105,9 +1104,35 @@ test_z (void)
   gchar *p = g_date_time_format (dt, "%z");
   g_assert_cmpstr (p, ==, "-0800");
   g_date_time_unref (dt);
+  g_time_zone_unref (tz);
   g_free (p);
 }
 
+static void
+test_strftime (void)
+{
+  /* this is probably going to cause various buggy libcs to explode... */
+#define TEST_FORMAT \
+  "a%a A%A b%b B%B c%c C%C d%d e%e F%F g%g G%G h%h H%H I%I j%j m%m M%M " \
+  "n%n p%p r%r R%R S%S t%t T%T u%u V%V w%w x%x X%X y%y Y%Y z%z Z%Z %%"
+  time_t t;
+
+  /* 127997 is prime, 1315005118 is now */
+  for (t = 0; t < 1315005118; t += 127997)
+    {
+      GDateTime *date_time;
+      gchar c_str[1000];
+      gchar *dt_str;
+
+      date_time = g_date_time_new_from_unix_local (t);
+      dt_str = g_date_time_format (date_time, TEST_FORMAT);
+      strftime (c_str, sizeof c_str, TEST_FORMAT, localtime (&t));
+      g_assert_cmpstr (c_str, ==, dt_str);
+      g_date_time_unref (date_time);
+      g_free (dt_str);
+    }
+}
+
 gint
 main (gint   argc,
       gchar *argv[])
@@ -1145,6 +1170,7 @@ main (gint   argc,
   g_test_add_func ("/GDateTime/new_full", test_GDateTime_new_full);
   g_test_add_func ("/GDateTime/now", test_GDateTime_now);
   g_test_add_func ("/GDateTime/printf", test_GDateTime_printf);
+  g_test_add_func ("/GDateTime/strftime", test_strftime);
   g_test_add_func ("/GDateTime/modifiers", test_modifiers);
   g_test_add_func ("/GDateTime/to_local", test_GDateTime_to_local);
   g_test_add_func ("/GDateTime/to_unix", test_GDateTime_to_unix);
