@@ -444,7 +444,6 @@ test_listing (void)
   gsize len;
   gchar *start;
   GError *error = NULL;
-  gboolean has_key;
 
   const gchar *data =
     "[group1]\n"
@@ -497,21 +496,6 @@ test_listing (void)
   g_key_file_has_key (keyfile, "no-such-group", "key", &error);
   check_error (&error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND);
 
-  g_assert (g_key_file_has_key_full (keyfile, "group1", "key1", &has_key, &error));
-  check_no_error (&error);
-  g_assert (has_key);
-
-  g_assert (g_key_file_has_key_full (keyfile, "group2", "key3", &has_key, &error));
-  check_no_error (&error);
-  g_assert (has_key);
-
-  g_assert (g_key_file_has_key_full (keyfile, "group2", "no-such-key", &has_key, &error));
-  g_assert (!has_key);
-  check_no_error (&error);
-
-  g_assert (!g_key_file_has_key_full (keyfile, "no-such-group", "key", &has_key, &error));
-  check_error (&error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND);
-
   g_key_file_free (keyfile);
 }
 
@@ -589,6 +573,9 @@ test_boolean (void)
   g_key_file_get_boolean (keyfile, "invalid", "key4", &error);
   check_error (&error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_INVALID_VALUE);
 
+  g_key_file_set_boolean (keyfile, "valid", "key1", FALSE);
+  check_boolean_value (keyfile, "valid", "key1", FALSE);
+
   g_key_file_free (keyfile);
 }
 
@@ -1324,6 +1311,13 @@ test_load (void)
   g_key_file_set_comment (file, NULL, NULL, "top comment", NULL);
 
   g_key_file_free (file);
+
+  file = g_key_file_new ();
+  error = NULL;
+  g_assert (!g_key_file_load_from_data_dirs (file, "keyfile-test.ini", NULL, 0, &error));
+  g_assert_error (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_NOT_FOUND);
+  g_error_free (error);
+  g_key_file_free (file);
 }
 
 static void
