@@ -432,6 +432,10 @@ test_compose (void)
   g_assert (!g_unichar_compose (0x0041, 0, &ch) && ch == 0);
   g_assert (!g_unichar_compose (0x0066, 0x0069, &ch) && ch == 0);
 
+  /* Tricky non-composable */
+  g_assert (!g_unichar_compose (0x0308, 0x0301, &ch) && ch == 0); /* !0x0344 */
+  g_assert (!g_unichar_compose (0x0F71, 0x0F72, &ch) && ch == 0); /* !0x0F73 */
+
   /* Singletons should not compose */
   g_assert (!g_unichar_compose (0x212B, 0, &ch) && ch == 0);
   g_assert (!g_unichar_compose (0x00C5, 0, &ch) && ch == 0);
@@ -466,6 +470,10 @@ test_decompose (void)
   g_assert (g_unichar_decompose (0x212B, &a, &b) && a == 0x00C5 && b == 0);
   g_assert (g_unichar_decompose (0x2126, &a, &b) && a == 0x03A9 && b == 0);
 
+  /* Tricky pairs */
+  g_assert (g_unichar_decompose (0x0344, &a, &b) && a == 0x0308 && b == 0x0301);
+  g_assert (g_unichar_decompose (0x0F73, &a, &b) && a == 0x0F71 && b == 0x0F72);
+
   /* Pairs */
   g_assert (g_unichar_decompose (0x00C5, &a, &b) && a == 0x0041 && b == 0x030A);
   g_assert (g_unichar_decompose (0x00F4, &a, &b) && a == 0x006F && b == 0x0302);
@@ -509,6 +517,10 @@ test_fully_decompose_canonical (void)
   TEST2 (0x212B, 0x0041, 0x030A);
   TEST1 (0x2126, 0x03A9);
 
+  /* Tricky pairs */
+  TEST2 (0x0344, 0x0308, 0x0301);
+  TEST2 (0x0F73, 0x0F71, 0x0F72);
+
   /* General */
   TEST2 (0x00C5, 0x0041, 0x030A);
   TEST2 (0x00F4, 0x006F, 0x0302);
@@ -555,6 +567,10 @@ test_canonical_decomposition (void)
   TEST2 (0x212B, 0x0041, 0x030A);
   TEST1 (0x2126, 0x03A9);
 
+  /* Tricky pairs */
+  TEST2 (0x0344, 0x0308, 0x0301);
+  TEST2 (0x0F73, 0x0F71, 0x0F72);
+
   /* General */
   TEST2 (0x00C5, 0x0041, 0x030A);
   TEST2 (0x00F4, 0x006F, 0x0302);
@@ -602,6 +618,18 @@ test_fully_decompose_len (void)
   }
 }
 
+static void
+test_iso15924 (void)
+{
+  g_assert_cmphex (0, ==, g_unicode_script_to_iso15924 (G_UNICODE_SCRIPT_INVALID_CODE));
+  g_assert_cmphex (0x5A7A7A7A, ==, g_unicode_script_to_iso15924 (1000));
+  g_assert_cmphex (0x41726162, ==, g_unicode_script_to_iso15924 (G_UNICODE_SCRIPT_ARABIC));
+
+  g_assert_cmphex (G_UNICODE_SCRIPT_INVALID_CODE, ==, g_unicode_script_from_iso15924 (0));
+  g_assert_cmphex (G_UNICODE_SCRIPT_UNKNOWN, ==, g_unicode_script_from_iso15924 (0x12345678));
+  g_assert_cmphex (G_UNICODE_SCRIPT_ARABIC, ==, g_unicode_script_from_iso15924 (0x41726162));
+}
+
 int
 main (int   argc,
       char *argv[])
@@ -623,6 +651,7 @@ main (int   argc,
   g_test_add_func ("/unicode/canonical-decomposition", test_canonical_decomposition);
   g_test_add_func ("/unicode/decompose-tail", test_decompose_tail);
   g_test_add_func ("/unicode/fully-decompose-len", test_fully_decompose_len);
+  g_test_add_func ("/unicode/iso15924", test_iso15924);
 
   return g_test_run();
 }
