@@ -1,4 +1,10 @@
 
+#include "config.h"
+
+#include "gobject.h"
+#include "genums.h"
+#include "gboxed.h"
+#include "gvaluetypes.h"
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -19,6 +25,7 @@
 #define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
 #define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
 #define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
 #else /* !G_ENABLE_DEBUG */
 /* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
  *          Do not access GValues directly in your code. Instead, use the
@@ -42,16 +49,17 @@
 #define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
 #define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:VOID (./gmarshal.list:26) */
+/* VOID:VOID (./gmarshal.list:6) */
 void
 g_cclosure_marshal_VOID__VOID (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__VOID) (gpointer     data1,
@@ -78,13 +86,13 @@ g_cclosure_marshal_VOID__VOID (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOOLEAN (./gmarshal.list:27) */
+/* VOID:BOOLEAN (./gmarshal.list:7) */
 void
 g_cclosure_marshal_VOID__BOOLEAN (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOOLEAN) (gpointer     data1,
@@ -113,13 +121,13 @@ g_cclosure_marshal_VOID__BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:CHAR (./gmarshal.list:28) */
+/* VOID:CHAR (./gmarshal.list:8) */
 void
 g_cclosure_marshal_VOID__CHAR (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__CHAR) (gpointer     data1,
@@ -148,13 +156,13 @@ g_cclosure_marshal_VOID__CHAR (GClosure     *closure,
             data2);
 }
 
-/* VOID:UCHAR (./gmarshal.list:29) */
+/* VOID:UCHAR (./gmarshal.list:9) */
 void
 g_cclosure_marshal_VOID__UCHAR (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UCHAR) (gpointer     data1,
@@ -183,13 +191,13 @@ g_cclosure_marshal_VOID__UCHAR (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT (./gmarshal.list:30) */
+/* VOID:INT (./gmarshal.list:10) */
 void
 g_cclosure_marshal_VOID__INT (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT) (gpointer     data1,
@@ -218,13 +226,13 @@ g_cclosure_marshal_VOID__INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT (./gmarshal.list:31) */
+/* VOID:UINT (./gmarshal.list:11) */
 void
 g_cclosure_marshal_VOID__UINT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT) (gpointer     data1,
@@ -253,13 +261,13 @@ g_cclosure_marshal_VOID__UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:LONG (./gmarshal.list:32) */
+/* VOID:LONG (./gmarshal.list:12) */
 void
 g_cclosure_marshal_VOID__LONG (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__LONG) (gpointer     data1,
@@ -288,13 +296,13 @@ g_cclosure_marshal_VOID__LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG (./gmarshal.list:33) */
+/* VOID:ULONG (./gmarshal.list:13) */
 void
 g_cclosure_marshal_VOID__ULONG (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ULONG) (gpointer     data1,
@@ -323,13 +331,13 @@ g_cclosure_marshal_VOID__ULONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM (./gmarshal.list:34) */
+/* VOID:ENUM (./gmarshal.list:14) */
 void
 g_cclosure_marshal_VOID__ENUM (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ENUM) (gpointer     data1,
@@ -358,13 +366,13 @@ g_cclosure_marshal_VOID__ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:FLAGS (./gmarshal.list:35) */
+/* VOID:FLAGS (./gmarshal.list:15) */
 void
 g_cclosure_marshal_VOID__FLAGS (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__FLAGS) (gpointer     data1,
@@ -393,13 +401,13 @@ g_cclosure_marshal_VOID__FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:FLOAT (./gmarshal.list:36) */
+/* VOID:FLOAT (./gmarshal.list:16) */
 void
 g_cclosure_marshal_VOID__FLOAT (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__FLOAT) (gpointer     data1,
@@ -428,13 +436,13 @@ g_cclosure_marshal_VOID__FLOAT (GClosure     *closure,
             data2);
 }
 
-/* VOID:DOUBLE (./gmarshal.list:37) */
+/* VOID:DOUBLE (./gmarshal.list:17) */
 void
 g_cclosure_marshal_VOID__DOUBLE (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__DOUBLE) (gpointer     data1,
@@ -463,13 +471,13 @@ g_cclosure_marshal_VOID__DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (./gmarshal.list:38) */
+/* VOID:STRING (./gmarshal.list:18) */
 void
 g_cclosure_marshal_VOID__STRING (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING) (gpointer     data1,
@@ -498,13 +506,13 @@ g_cclosure_marshal_VOID__STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:PARAM (./gmarshal.list:39) */
+/* VOID:PARAM (./gmarshal.list:19) */
 void
 g_cclosure_marshal_VOID__PARAM (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__PARAM) (gpointer     data1,
@@ -533,13 +541,13 @@ g_cclosure_marshal_VOID__PARAM (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED (./gmarshal.list:40) */
+/* VOID:BOXED (./gmarshal.list:20) */
 void
 g_cclosure_marshal_VOID__BOXED (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED) (gpointer     data1,
@@ -568,13 +576,13 @@ g_cclosure_marshal_VOID__BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (./gmarshal.list:41) */
+/* VOID:POINTER (./gmarshal.list:21) */
 void
 g_cclosure_marshal_VOID__POINTER (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER) (gpointer     data1,
@@ -603,13 +611,13 @@ g_cclosure_marshal_VOID__POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (./gmarshal.list:42) */
+/* VOID:OBJECT (./gmarshal.list:22) */
 void
 g_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT) (gpointer     data1,
@@ -638,13 +646,48 @@ g_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,POINTER (./gmarshal.list:45) */
+/* VOID:VARIANT (./gmarshal.list:23) */
+void
+g_cclosure_marshal_VOID__VARIANT (GClosure     *closure,
+                                  GValue       *return_value G_GNUC_UNUSED,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
+                                  gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__VARIANT) (gpointer     data1,
+                                              gpointer     arg_1,
+                                              gpointer     data2);
+  register GMarshalFunc_VOID__VARIANT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__VARIANT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_variant (param_values + 1),
+            data2);
+}
+
+/* VOID:UINT,POINTER (./gmarshal.list:26) */
 void
 g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
-                                       GValue       *return_value,
+                                       GValue       *return_value G_GNUC_UNUSED,
                                        guint         n_param_values,
                                        const GValue *param_values,
-                                       gpointer      invocation_hint,
+                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_POINTER) (gpointer     data1,
@@ -675,13 +718,13 @@ g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* BOOL:FLAGS (./gmarshal.list:46) */
+/* BOOL:FLAGS (./gmarshal.list:27) */
 void
 g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
-                                   GValue       *return_value,
+                                   GValue       *return_value G_GNUC_UNUSED,
                                    guint         n_param_values,
                                    const GValue *param_values,
-                                   gpointer      invocation_hint,
+                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                    gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__FLAGS) (gpointer     data1,
@@ -714,13 +757,13 @@ g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* STRING:OBJECT,POINTER (./gmarshal.list:47) */
+/* STRING:OBJECT,POINTER (./gmarshal.list:28) */
 void
 g_cclosure_marshal_STRING__OBJECT_POINTER (GClosure     *closure,
-                                           GValue       *return_value,
+                                           GValue       *return_value G_GNUC_UNUSED,
                                            guint         n_param_values,
                                            const GValue *param_values,
-                                           gpointer      invocation_hint,
+                                           gpointer      invocation_hint G_GNUC_UNUSED,
                                            gpointer      marshal_data)
 {
   typedef gchar* (*GMarshalFunc_STRING__OBJECT_POINTER) (gpointer     data1,
@@ -755,3 +798,44 @@ g_cclosure_marshal_STRING__OBJECT_POINTER (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
+/* BOOL:BOXED,BOXED (./gmarshal.list:29) */
+void
+g_cclosure_marshal_BOOLEAN__BOXED_BOXED (GClosure     *closure,
+                                         GValue       *return_value G_GNUC_UNUSED,
+                                         guint         n_param_values,
+                                         const GValue *param_values,
+                                         gpointer      invocation_hint G_GNUC_UNUSED,
+                                         gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__BOXED_BOXED) (gpointer     data1,
+                                                         gpointer     arg_1,
+                                                         gpointer     arg_2,
+                                                         gpointer     data2);
+  register GMarshalFunc_BOOLEAN__BOXED_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__BOXED_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_boxed (param_values + 1),
+                       g_marshal_value_peek_boxed (param_values + 2),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
